==> haskell-pandoc-crossref-0.2.4.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.2.4.1
id: pandoc-crossref-0.2.4.1-B68hx3tIZmuA9yLdzfsVTY
key: pandoc-crossref-0.2.4.1-B68hx3tIZmuA9yLdzfsVTY
license: GPL-2
maintainer: root@livid.pp.ru
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.Settings Text.Pandoc.CrossRef.Util.Meta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Gap
                Text.Pandoc.CrossRef.Util.PandocOrphans
abi: 14112f6968f120b8cd847be38a63c992
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.4.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.4.1
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.2.4.1-B68hx3tIZmuA9yLdzfsVTY
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    data-accessor-0.2.2.7-8YIdFyGw7Iv38wc1N9wMCB
    data-accessor-template-0.2.1.13-JtKYNqLEhnq39z3SoVKvud
    data-accessor-transformers-0.2.1.7-6TVC9nFjSqUC6vJHuIemG9
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM pandoc-1.18-1dXInER0UDpHMuO8Xx9wRs
    pandoc-types-1.17.0.4-IWGdyFdzavVAZy52ThgJOr
    roman-numerals-0.5.1.5-JFncje0j4Ta5hlOmnjSBkn
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
    utility-ht-0.0.12-IQc75ZjtSJC6jKWDjW00eb
    yaml-0.8.21.1-1B9YQ1HpOImCkagVfuaKjO
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-crossref-0.2.4.1-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pandoc-crossref.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pandoc-crossref
version: 0.2.4.1
id: pandoc-crossref-0.2.4.1-4gJaXdrHj0oGTt2UxUTELk
key: pandoc-crossref-0.2.4.1-4gJaXdrHj0oGTt2UxUTELk
license: GPL-2
maintainer: root@livid.pp.ru
synopsis: Pandoc filter for cross-references
description:
    pandoc-crossref is a pandoc filter for numbering figures, equations, tables and cross-references to them.
category: Text
author: Nikolay Yakimov
exposed: True
exposed-modules:
    Text.Pandoc.CrossRef
hidden-modules: Text.Pandoc.CrossRef.References
                Text.Pandoc.CrossRef.References.Blocks
                Text.Pandoc.CrossRef.References.List
                Text.Pandoc.CrossRef.References.Refs
                Text.Pandoc.CrossRef.References.Types
                Text.Pandoc.CrossRef.Util.Settings Text.Pandoc.CrossRef.Util.Meta
                Text.Pandoc.CrossRef.Util.Options
                Text.Pandoc.CrossRef.Util.Template Text.Pandoc.CrossRef.Util.Util
                Text.Pandoc.CrossRef.Util.CustomLabels
                Text.Pandoc.CrossRef.Util.CodeBlockCaptions
                Text.Pandoc.CrossRef.Util.ModifyMeta
                Text.Pandoc.CrossRef.Util.Settings.Gen
                Text.Pandoc.CrossRef.Util.Settings.Template
                Text.Pandoc.CrossRef.Util.Gap
                Text.Pandoc.CrossRef.Util.PandocOrphans
abi: 59490d81bbbb41142f9e1b9e14558c51
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.4.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/pandoc-crossref-0.2.4.1
data-dir: /usr/share/pandoc-crossref
hs-libraries: HSpandoc-crossref-0.2.4.1-4gJaXdrHj0oGTt2UxUTELk
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    data-accessor-0.2.2.7-8YIdFyGw7Iv38wc1N9wMCB
    data-accessor-template-0.2.1.13-JtKYNqLEhnq39z3SoVKvud
    data-accessor-transformers-0.2.1.7-6TVC9nFjSqUC6vJHuIemG9
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM pandoc-1.18-EOFghBXV5FQ8upfoPrQPVO
    pandoc-types-1.17.0.4-IWGdyFdzavVAZy52ThgJOr
    roman-numerals-0.5.1.5-JFncje0j4Ta5hlOmnjSBkn
    syb-0.6-C65vWCsht6A8uLstpQIXyj template-haskell-2.11.0.0
    utility-ht-0.0.12-IQc75ZjtSJC6jKWDjW00eb
    yaml-0.8.21.1-khAXLHhid55fsKK4qPmKr
haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
haddock-html: /usr/share/doc/pandoc-crossref/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
